@@ -279,7 +279,7 @@ impl<'a> TryFrom<FileData> for SignableCandidate<'static> {
     type Error = anyhow::Error;
 
     fn try_from(file: FileData) -> Result<Self, Self::Error> {
-        Ok(Self::Data(Cow::Owned(file.resolve()?)))
+        Ok(Self::Data(Cow::Owned(file.resolve_content()?)))
     }
 }
 
@@ -287,7 +287,7 @@ impl<'a> TryFrom<&FileData> for SignableCandidate<'static> {
     type Error = anyhow::Error;
 
     fn try_from(file: &FileData) -> Result<Self, Self::Error> {
-        Ok(Self::Data(Cow::Owned(file.resolve()?)))
+        Ok(Self::Data(Cow::Owned(file.resolve_content()?)))
     }
 }
 
@@ -295,7 +295,7 @@ impl<'a> TryFrom<FileEntry> for SignableCandidate<'static> {
     type Error = anyhow::Error;
 
     fn try_from(entry: FileEntry) -> Result<Self, Self::Error> {
-        SignableCandidate::try_from(entry.data)
+        SignableCandidate::try_from(entry.file_data())
     }
 }
 
@@ -303,7 +303,7 @@ impl<'a> TryFrom<&FileEntry> for SignableCandidate<'static> {
     type Error = anyhow::Error;
 
     fn try_from(entry: &FileEntry) -> Result<Self, Self::Error> {
-        SignableCandidate::try_from(&entry.data)
+        SignableCandidate::try_from(entry.file_data())
     }
 }
 
@@ -311,7 +311,7 @@ impl<'a> TryFrom<File> for SignableCandidate<'static> {
     type Error = anyhow::Error;
 
     fn try_from(file: File) -> Result<Self, Self::Error> {
-        SignableCandidate::try_from(file.entry.data)
+        SignableCandidate::try_from(file.entry().file_data())
     }
 }
 
@@ -319,7 +319,7 @@ impl<'a> TryFrom<&File> for SignableCandidate<'static> {
     type Error = anyhow::Error;
 
     fn try_from(file: &File) -> Result<Self, Self::Error> {
-        SignableCandidate::try_from(&file.entry.data)
+        SignableCandidate::try_from(file.entry().file_data())
     }
 }
 
@@ -540,7 +540,7 @@ pub fn path_signable(path: impl AsRef<Path>) -> Result<Signability, SigningError
                 Err(e) => Signability::UnsignableMachoError(e),
             });
         }
-    } else if path.is_dir() && tugger_apple_bundle::DirectoryBundle::new_from_path(path).is_ok() {
+    } else if path.is_dir() && apple_bundles::DirectoryBundle::new_from_path(path).is_ok() {
         return Ok(Signability::Signable(Signable::AppleBundle(
             path.to_path_buf(),
         )));
